aboutsummaryrefslogtreecommitdiff
path: root/gdb/coffread.c
diff options
context:
space:
mode:
authorJim Kingdon <jkingdon@engr.sgi.com>1993-09-01 23:11:30 +0000
committerJim Kingdon <jkingdon@engr.sgi.com>1993-09-01 23:11:30 +0000
commit3ffb74b9ab078a2dc51cd1bddcf99b5c13894653 (patch)
tree486e2c996b1a2c65fd6c6f321d767a3dcd47e623 /gdb/coffread.c
parentc398de0cddd0a2215e9d9c0f563d40aa5f554692 (diff)
downloadgdb-3ffb74b9ab078a2dc51cd1bddcf99b5c13894653.zip
gdb-3ffb74b9ab078a2dc51cd1bddcf99b5c13894653.tar.gz
gdb-3ffb74b9ab078a2dc51cd1bddcf99b5c13894653.tar.bz2
* coffread.c: Re-work a lot of the coff-specific stuff to use stuff
in buildsym.c. This includes coff_finish_block, coff_context_stack, coff_local_symbols, coff_file_symbols, coff_global_symbols, coff_end_symtab and coff_add_symbol_to_list. (read_enum_type): Deal with it now that we have a "struct pending" not a "struct coff_pending".
Diffstat (limited to 'gdb/coffread.c')
-rw-r--r--gdb/coffread.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/gdb/coffread.c b/gdb/coffread.c
index 6ccf456..7c714c2 100644
--- a/gdb/coffread.c
+++ b/gdb/coffread.c
@@ -347,8 +347,10 @@ static void
coff_start_symtab ()
{
start_symtab (
- /* We fill in the filename later. */
- "",
+ /* We fill in the filename later. But start_symtab
+ expects something we can later free() (in end_symtab).
+ FIXME: leaks memory. */
+ savestring ("", 0),
/* We never know the directory name for COFF. */
NULL,
/* The start address is irrelevant, since we set